@@ -8,12 +8,14 @@ from borgmatic.borg import extract as module
 from ..test_verbosity import insert_logging_mock
 
 
-def insert_execute_command_mock(command, working_directory=None):
+def insert_execute_command_mock(command, working_directory=None, borg_exit_codes=None):
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command').with_args(
         command,
         working_directory=working_directory,
         extra_environment=None,
+        borg_local_path=command[0],
+        borg_exit_codes=borg_exit_codes,
     ).once()
 
 
@@ -99,6 +101,25 @@ def test_extract_last_archive_dry_run_calls_borg_via_local_path():
     )
 
 
+def test_extract_last_archive_dry_run_calls_borg_using_exit_codes():
+    flexmock(module.rlist).should_receive('resolve_archive_name').and_return('archive')
+    borg_exit_codes = flexmock()
+    insert_execute_command_mock(
+        ('borg', 'extract', '--dry-run', 'repo::archive'), borg_exit_codes=borg_exit_codes
+    )
+    flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
+        ('repo::archive',)
+    )
+
+    module.extract_last_archive_dry_run(
+        config={'borg_exit_codes': borg_exit_codes},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
+        repository_path='repo',
+        lock_wait=None,
+    )
+
+
 def test_extract_last_archive_dry_run_calls_borg_with_remote_path_flags():
     flexmock(module.rlist).should_receive('resolve_archive_name').and_return('archive')
     insert_execute_command_mock(
@@ -174,6 +195,54 @@ def test_extract_archive_calls_borg_with_path_flags():
     )
 
 
+def test_extract_archive_calls_borg_with_local_path():
+    flexmock(module.os.path).should_receive('abspath').and_return('repo')
+    insert_execute_command_mock(('borg1', 'extract', 'repo::archive'))
+    flexmock(module.feature).should_receive('available').and_return(True)
+    flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
+        ('repo::archive',)
+    )
+    flexmock(module.borgmatic.config.validate).should_receive(
+        'normalize_repository_path'
+    ).and_return('repo')
+
+    module.extract_archive(
+        dry_run=False,
+        repository='repo',
+        archive='archive',
+        paths=None,
+        config={},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
+        local_path='borg1',
+    )
+
+
+def test_extract_archive_calls_borg_with_exit_codes():
+    flexmock(module.os.path).should_receive('abspath').and_return('repo')
+    borg_exit_codes = flexmock()
+    insert_execute_command_mock(
+        ('borg', 'extract', 'repo::archive'), borg_exit_codes=borg_exit_codes
+    )
+    flexmock(module.feature).should_receive('available').and_return(True)
+    flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
+        ('repo::archive',)
+    )
+    flexmock(module.borgmatic.config.validate).should_receive(
+        'normalize_repository_path'
+    ).and_return('repo')
+
+    module.extract_archive(
+        dry_run=False,
+        repository='repo',
+        archive='archive',
+        paths=None,
+        config={'borg_exit_codes': borg_exit_codes},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
+    )
+
+
 def test_extract_archive_calls_borg_with_remote_path_flags():
     flexmock(module.os.path).should_receive('abspath').and_return('repo')
     insert_execute_command_mock(('borg', 'extract', '--remote-path', 'borg1', 'repo::archive'))
@@ -470,6 +539,8 @@ def test_extract_archive_calls_borg_with_progress_parameter():
         output_file=module.DO_NOT_CAPTURE,
         working_directory=None,
         extra_environment=None,
+        borg_local_path='borg',
+        borg_exit_codes=None,
     ).once()
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
@@ -518,6 +589,8 @@ def test_extract_archive_calls_borg_with_stdout_parameter_and_returns_process():
         working_directory=None,
         run_to_completion=False,
         extra_environment=None,
+        borg_local_path='borg',
+        borg_exit_codes=None,
     ).and_return(process).once()
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
@@ -549,6 +622,8 @@ def test_extract_archive_skips_abspath_for_remote_repository():
         ('borg', 'extract', 'server:repo::archive'),
         working_directory=None,
         extra_environment=None,
+        borg_local_path='borg',
+        borg_exit_codes=None,
     ).once()
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
