@@ -7,7 +7,7 @@ from borgmatic.config import generate as module
 
 
 def test_schema_to_sample_configuration_generates_config_map_with_examples():
-    flexmock(module.yaml.comments).should_receive('CommentedMap').replace_with(OrderedDict)
+    flexmock(module.ruamel.yaml.comments).should_receive('CommentedMap').replace_with(OrderedDict)
     flexmock(module).should_receive('add_comments_to_configuration_object')
     schema = {
         'type': 'object',
@@ -32,7 +32,7 @@ def test_schema_to_sample_configuration_generates_config_map_with_examples():
 
 
 def test_schema_to_sample_configuration_generates_config_sequence_of_strings_with_example():
-    flexmock(module.yaml.comments).should_receive('CommentedSeq').replace_with(list)
+    flexmock(module.ruamel.yaml.comments).should_receive('CommentedSeq').replace_with(list)
     flexmock(module).should_receive('add_comments_to_configuration_sequence')
     schema = {'type': 'array', 'items': {'type': 'string'}, 'example': ['hi']}
 
@@ -42,7 +42,7 @@ def test_schema_to_sample_configuration_generates_config_sequence_of_strings_wit
 
 
 def test_schema_to_sample_configuration_generates_config_sequence_of_maps_with_examples():
-    flexmock(module.yaml.comments).should_receive('CommentedSeq').replace_with(list)
+    flexmock(module.ruamel.yaml.comments).should_receive('CommentedSeq').replace_with(list)
     flexmock(module).should_receive('add_comments_to_configuration_sequence')
     flexmock(module).should_receive('add_comments_to_configuration_object')
     schema = {
@@ -71,7 +71,7 @@ def test_merge_source_configuration_into_destination_inserts_map_fields():
     destination_config = {'foo': 'dest1', 'bar': 'dest2'}
     source_config = {'foo': 'source1', 'baz': 'source2'}
     flexmock(module).should_receive('remove_commented_out_sentinel')
-    flexmock(module).should_receive('yaml.comments.CommentedSeq').replace_with(list)
+    flexmock(module).should_receive('ruamel.yaml.comments.CommentedSeq').replace_with(list)
 
     module.merge_source_configuration_into_destination(destination_config, source_config)
 
@@ -82,7 +82,7 @@ def test_merge_source_configuration_into_destination_inserts_nested_map_fields()
     destination_config = {'foo': {'first': 'dest1', 'second': 'dest2'}, 'bar': 'dest3'}
     source_config = {'foo': {'first': 'source1'}}
     flexmock(module).should_receive('remove_commented_out_sentinel')
-    flexmock(module).should_receive('yaml.comments.CommentedSeq').replace_with(list)
+    flexmock(module).should_receive('ruamel.yaml.comments.CommentedSeq').replace_with(list)
 
     module.merge_source_configuration_into_destination(destination_config, source_config)
 
@@ -93,7 +93,7 @@ def test_merge_source_configuration_into_destination_inserts_sequence_fields():
     destination_config = {'foo': ['dest1', 'dest2'], 'bar': ['dest3'], 'baz': ['dest4']}
     source_config = {'foo': ['source1'], 'bar': ['source2', 'source3']}
     flexmock(module).should_receive('remove_commented_out_sentinel')
-    flexmock(module).should_receive('yaml.comments.CommentedSeq').replace_with(list)
+    flexmock(module).should_receive('ruamel.yaml.comments.CommentedSeq').replace_with(list)
 
     module.merge_source_configuration_into_destination(destination_config, source_config)
 
@@ -108,7 +108,7 @@ def test_merge_source_configuration_into_destination_inserts_sequence_of_maps():
     destination_config = {'foo': [{'first': 'dest1', 'second': 'dest2'}], 'bar': 'dest3'}
     source_config = {'foo': [{'first': 'source1'}, {'other': 'source2'}]}
     flexmock(module).should_receive('remove_commented_out_sentinel')
-    flexmock(module).should_receive('yaml.comments.CommentedSeq').replace_with(list)
+    flexmock(module).should_receive('ruamel.yaml.comments.CommentedSeq').replace_with(list)
 
     module.merge_source_configuration_into_destination(destination_config, source_config)
 
