@@ -50,6 +50,14 @@ def test_make_extra_environment_without_cli_password_or_configured_password_does
     assert 'PGPASSWORD' not in extra
 
 
+def test_make_extra_environment_without_ssl_mode_does_not_set_ssl_mode():
+    database = {'name': 'foo'}
+
+    extra = module.make_extra_environment(database)
+
+    assert 'PGSSLMODE' not in extra
+
+
 def test_database_names_to_dump_passes_through_individual_database_name():
     database = {'name': 'foo'}
 
@@ -164,11 +172,17 @@ def test_database_names_to_dump_with_all_and_format_excludes_particular_database
 
 
 def test_database_names_to_dump_with_all_and_psql_command_uses_custom_command():
-    database = {'name': 'all', 'format': 'custom', 'psql_command': 'docker exec mycontainer psql'}
+    database = {
+        'name': 'all',
+        'format': 'custom',
+        'psql_command': 'docker exec --workdir * mycontainer psql',
+    }
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         (
             'docker',
             'exec',
+            '--workdir',
+            "'*'",  # Should get shell escaped to prevent injection attacks.
             'mycontainer',
             'psql',
             '--list',
@@ -345,6 +359,42 @@ def test_dump_data_sources_runs_pg_dump_with_username_and_password():
     assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == [process]
 
 
+def test_dump_data_sources_with_username_injection_attack_gets_escaped():
+    databases = [{'name': 'foo', 'username': 'postgres; naughty-command', 'password': 'trustsome1'}]
+    process = flexmock()
+    flexmock(module).should_receive('make_extra_environment').and_return(
+        {'PGPASSWORD': 'trustsome1', 'PGSSLMODE': 'disable'}
+    )
+    flexmock(module).should_receive('make_dump_path').and_return('')
+    flexmock(module).should_receive('database_names_to_dump').and_return(('foo',))
+    flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return(
+        'databases/localhost/foo'
+    )
+    flexmock(module.os.path).should_receive('exists').and_return(False)
+    flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+
+    flexmock(module).should_receive('execute_command').with_args(
+        (
+            'pg_dump',
+            '--no-password',
+            '--clean',
+            '--if-exists',
+            '--username',
+            "'postgres; naughty-command'",
+            '--format',
+            'custom',
+            'foo',
+            '>',
+            'databases/localhost/foo',
+        ),
+        shell=True,
+        extra_environment={'PGPASSWORD': 'trustsome1', 'PGSSLMODE': 'disable'},
+        run_to_completion=False,
+    ).and_return(process).once()
+
+    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == [process]
+
+
 def test_dump_data_sources_runs_pg_dump_with_directory_format():
     databases = [{'name': 'foo', 'format': 'directory'}]
     flexmock(module).should_receive('make_extra_environment').and_return({'PGSSLMODE': 'disable'})
@@ -432,7 +482,7 @@ def test_dump_data_sources_runs_pg_dumpall_for_all_databases():
 
 
 def test_dump_data_sources_runs_non_default_pg_dump():
-    databases = [{'name': 'foo', 'pg_dump_command': 'special_pg_dump'}]
+    databases = [{'name': 'foo', 'pg_dump_command': 'special_pg_dump --compress *'}]
     process = flexmock()
     flexmock(module).should_receive('make_extra_environment').and_return({'PGSSLMODE': 'disable'})
     flexmock(module).should_receive('make_dump_path').and_return('')
@@ -446,6 +496,8 @@ def test_dump_data_sources_runs_non_default_pg_dump():
     flexmock(module).should_receive('execute_command').with_args(
         (
             'special_pg_dump',
+            '--compress',
+            "'*'",  # Should get shell escaped to prevent injection attacks.
             '--no-password',
             '--clean',
             '--if-exists',
@@ -943,8 +995,8 @@ def test_restore_data_source_dump_runs_non_default_pg_restore_and_psql():
     hook_config = [
         {
             'name': 'foo',
-            'pg_restore_command': 'docker exec mycontainer pg_restore',
-            'psql_command': 'docker exec mycontainer psql',
+            'pg_restore_command': 'docker exec --workdir * mycontainer pg_restore',
+            'psql_command': 'docker exec --workdir * mycontainer psql',
             'schemas': None,
         }
     ]
@@ -957,6 +1009,8 @@ def test_restore_data_source_dump_runs_non_default_pg_restore_and_psql():
         (
             'docker',
             'exec',
+            '--workdir',
+            "'*'",  # Should get shell escaped to prevent injection attacks.
             'mycontainer',
             'pg_restore',
             '--no-password',
@@ -975,6 +1029,8 @@ def test_restore_data_source_dump_runs_non_default_pg_restore_and_psql():
         (
             'docker',
             'exec',
+            '--workdir',
+            "'*'",  # Should get shell escaped to prevent injection attacks.
             'mycontainer',
             'psql',
             '--no-password',
