@@ -7,32 +7,49 @@ from borgmatic import execute as module
 
 
 @pytest.mark.parametrize(
-    'command,exit_code,borg_local_path,expected_result',
+    'command,exit_code,borg_local_path,borg_exit_codes,expected_result',
     (
-        (['grep'], 2, None, True),
-        (['grep'], 2, 'borg', True),
-        (['borg'], 2, 'borg', True),
-        (['borg1'], 2, 'borg1', True),
-        (['grep'], 1, None, True),
-        (['grep'], 1, 'borg', True),
-        (['borg'], 1, 'borg', False),
-        (['borg1'], 1, 'borg1', False),
-        (['grep'], 0, None, False),
-        (['grep'], 0, 'borg', False),
-        (['borg'], 0, 'borg', False),
-        (['borg1'], 0, 'borg1', False),
+        (['grep'], 2, None, None, module.Exit_status.ERROR),
+        (['grep'], 2, 'borg', None, module.Exit_status.ERROR),
+        (['borg'], 2, 'borg', None, module.Exit_status.ERROR),
+        (['borg1'], 2, 'borg1', None, module.Exit_status.ERROR),
+        (['grep'], 1, None, None, module.Exit_status.ERROR),
+        (['grep'], 1, 'borg', None, module.Exit_status.ERROR),
+        (['borg'], 1, 'borg', None, module.Exit_status.WARNING),
+        (['borg1'], 1, 'borg1', None, module.Exit_status.WARNING),
+        (['grep'], 100, None, None, module.Exit_status.ERROR),
+        (['grep'], 100, 'borg', None, module.Exit_status.ERROR),
+        (['borg'], 100, 'borg', None, module.Exit_status.WARNING),
+        (['borg1'], 100, 'borg1', None, module.Exit_status.WARNING),
+        (['grep'], 0, None, None, module.Exit_status.SUCCESS),
+        (['grep'], 0, 'borg', None, module.Exit_status.SUCCESS),
+        (['borg'], 0, 'borg', None, module.Exit_status.SUCCESS),
+        (['borg1'], 0, 'borg1', None, module.Exit_status.SUCCESS),
         # -9 exit code occurs when child process get SIGKILLed.
-        (['grep'], -9, None, True),
-        (['grep'], -9, 'borg', True),
-        (['borg'], -9, 'borg', True),
-        (['borg1'], -9, 'borg1', True),
-        (['borg'], None, None, False),
+        (['grep'], -9, None, None, module.Exit_status.ERROR),
+        (['grep'], -9, 'borg', None, module.Exit_status.ERROR),
+        (['borg'], -9, 'borg', None, module.Exit_status.ERROR),
+        (['borg1'], -9, 'borg1', None, module.Exit_status.ERROR),
+        (['borg'], None, None, None, module.Exit_status.STILL_RUNNING),
+        (['borg'], 1, 'borg', [], module.Exit_status.WARNING),
+        (['borg'], 1, 'borg', [{}], module.Exit_status.WARNING),
+        (['borg'], 1, 'borg', [{'code': 1}], module.Exit_status.WARNING),
+        (['grep'], 1, 'borg', [{'code': 100, 'treat_as': 'error'}], module.Exit_status.ERROR),
+        (['borg'], 1, 'borg', [{'code': 100, 'treat_as': 'error'}], module.Exit_status.WARNING),
+        (['borg'], 1, 'borg', [{'code': 1, 'treat_as': 'error'}], module.Exit_status.ERROR),
+        (['borg'], 2, 'borg', [{'code': 99, 'treat_as': 'warning'}], module.Exit_status.ERROR),
+        (['borg'], 2, 'borg', [{'code': 2, 'treat_as': 'warning'}], module.Exit_status.WARNING),
+        (['borg'], 100, 'borg', [{'code': 1, 'treat_as': 'error'}], module.Exit_status.WARNING),
+        (['borg'], 100, 'borg', [{'code': 100, 'treat_as': 'error'}], module.Exit_status.ERROR),
     ),
 )
-def test_exit_code_indicates_error_respects_exit_code_and_borg_local_path(
-    command, exit_code, borg_local_path, expected_result
+def test_interpret_exit_code_respects_exit_code_and_borg_local_path(
+    command, exit_code, borg_local_path, borg_exit_codes, expected_result
 ):
-    assert module.exit_code_indicates_error(command, exit_code, borg_local_path) is expected_result
+    assert (
+        module.interpret_exit_code(command, exit_code, borg_local_path, borg_exit_codes)
+        is expected_result
+    )
 
 
 def test_command_for_process_converts_sequence_command_to_string():
@@ -100,8 +117,39 @@ def test_append_last_lines_with_output_log_level_none_appends_captured_output():
     assert captured_output == ['captured', 'line']
 
 
+@pytest.mark.parametrize(
+    'full_command,input_file,output_file,environment,expected_result',
+    (
+        (('foo', 'bar'), None, None, None, 'foo bar'),
+        (('foo', 'bar'), flexmock(name='input'), None, None, 'foo bar < input'),
+        (('foo', 'bar'), None, flexmock(name='output'), None, 'foo bar > output'),
+        (
+            ('foo', 'bar'),
+            flexmock(name='input'),
+            flexmock(name='output'),
+            None,
+            'foo bar < input > output',
+        ),
+        (
+            ('foo', 'bar'),
+            None,
+            None,
+            {'DBPASS': 'secret', 'OTHER': 'thing'},
+            'DBPASS=*** OTHER=*** foo bar',
+        ),
+    ),
+)
+def test_log_command_logs_command_constructed_from_arguments(
+    full_command, input_file, output_file, environment, expected_result
+):
+    flexmock(module.logger).should_receive('debug').with_args(expected_result).once()
+
+    module.log_command(full_command, input_file, output_file, environment)
+
+
 def test_execute_command_calls_full_command():
     full_command = ['foo', 'bar']
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('Popen').with_args(
         full_command,
@@ -122,6 +170,7 @@ def test_execute_command_calls_full_command():
 def test_execute_command_calls_full_command_with_output_file():
     full_command = ['foo', 'bar']
     output_file = flexmock(name='test')
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('Popen').with_args(
         full_command,
@@ -141,11 +190,12 @@ def test_execute_command_calls_full_command_with_output_file():
 
 def test_execute_command_calls_full_command_without_capturing_output():
     full_command = ['foo', 'bar']
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('Popen').with_args(
         full_command, stdin=None, stdout=None, stderr=None, shell=False, env=None, cwd=None
     ).and_return(flexmock(wait=lambda: 0)).once()
-    flexmock(module).should_receive('exit_code_indicates_error').and_return(False)
+    flexmock(module).should_receive('interpret_exit_code').and_return(module.Exit_status.SUCCESS)
     flexmock(module).should_receive('log_outputs')
 
     output = module.execute_command(full_command, output_file=module.DO_NOT_CAPTURE)
@@ -156,6 +206,7 @@ def test_execute_command_calls_full_command_without_capturing_output():
 def test_execute_command_calls_full_command_with_input_file():
     full_command = ['foo', 'bar']
     input_file = flexmock(name='test')
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('Popen').with_args(
         full_command,
@@ -175,6 +226,7 @@ def test_execute_command_calls_full_command_with_input_file():
 
 def test_execute_command_calls_full_command_with_shell():
     full_command = ['foo', 'bar']
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('Popen').with_args(
         ' '.join(full_command),
@@ -194,6 +246,7 @@ def test_execute_command_calls_full_command_with_shell():
 
 def test_execute_command_calls_full_command_with_extra_environment():
     full_command = ['foo', 'bar']
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('Popen').with_args(
         full_command,
@@ -213,6 +266,7 @@ def test_execute_command_calls_full_command_with_extra_environment():
 
 def test_execute_command_calls_full_command_with_working_directory():
     full_command = ['foo', 'bar']
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('Popen').with_args(
         full_command,
@@ -233,6 +287,7 @@ def test_execute_command_calls_full_command_with_working_directory():
 def test_execute_command_without_run_to_completion_returns_process():
     full_command = ['foo', 'bar']
     process = flexmock()
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('Popen').with_args(
         full_command,
@@ -251,6 +306,7 @@ def test_execute_command_without_run_to_completion_returns_process():
 def test_execute_command_and_capture_output_returns_stdout():
     full_command = ['foo', 'bar']
     expected_output = '[]'
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('check_output').with_args(
         full_command, stderr=None, shell=False, env=None, cwd=None
@@ -264,6 +320,7 @@ def test_execute_command_and_capture_output_returns_stdout():
 def test_execute_command_and_capture_output_with_capture_stderr_returns_stderr():
     full_command = ['foo', 'bar']
     expected_output = '[]'
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('check_output').with_args(
         full_command, stderr=module.subprocess.STDOUT, shell=False, env=None, cwd=None
@@ -278,11 +335,14 @@ def test_execute_command_and_capture_output_returns_output_when_process_error_is
     full_command = ['foo', 'bar']
     expected_output = '[]'
     err_output = b'[]'
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('check_output').with_args(
         full_command, stderr=None, shell=False, env=None, cwd=None
     ).and_raise(subprocess.CalledProcessError(1, full_command, err_output)).once()
-    flexmock(module).should_receive('exit_code_indicates_error').and_return(False).once()
+    flexmock(module).should_receive('interpret_exit_code').and_return(
+        module.Exit_status.SUCCESS
+    ).once()
 
     output = module.execute_command_and_capture_output(full_command)
 
@@ -292,11 +352,14 @@ def test_execute_command_and_capture_output_returns_output_when_process_error_is
 def test_execute_command_and_capture_output_raises_when_command_errors():
     full_command = ['foo', 'bar']
     expected_output = '[]'
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('check_output').with_args(
         full_command, stderr=None, shell=False, env=None, cwd=None
     ).and_raise(subprocess.CalledProcessError(2, full_command, expected_output)).once()
-    flexmock(module).should_receive('exit_code_indicates_error').and_return(True).once()
+    flexmock(module).should_receive('interpret_exit_code').and_return(
+        module.Exit_status.ERROR
+    ).once()
 
     with pytest.raises(subprocess.CalledProcessError):
         module.execute_command_and_capture_output(full_command)
@@ -305,6 +368,7 @@ def test_execute_command_and_capture_output_raises_when_command_errors():
 def test_execute_command_and_capture_output_returns_output_with_shell():
     full_command = ['foo', 'bar']
     expected_output = '[]'
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('check_output').with_args(
         'foo bar', stderr=None, shell=True, env=None, cwd=None
@@ -318,6 +382,7 @@ def test_execute_command_and_capture_output_returns_output_with_shell():
 def test_execute_command_and_capture_output_returns_output_with_extra_environment():
     full_command = ['foo', 'bar']
     expected_output = '[]'
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('check_output').with_args(
         full_command,
@@ -337,6 +402,7 @@ def test_execute_command_and_capture_output_returns_output_with_extra_environmen
 def test_execute_command_and_capture_output_returns_output_with_working_directory():
     full_command = ['foo', 'bar']
     expected_output = '[]'
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('check_output').with_args(
         full_command, stderr=None, shell=False, env=None, cwd='/working'
@@ -352,6 +418,7 @@ def test_execute_command_and_capture_output_returns_output_with_working_director
 def test_execute_command_with_processes_calls_full_command():
     full_command = ['foo', 'bar']
     processes = (flexmock(),)
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('Popen').with_args(
         full_command,
@@ -372,6 +439,7 @@ def test_execute_command_with_processes_calls_full_command():
 def test_execute_command_with_processes_returns_output_with_output_log_level_none():
     full_command = ['foo', 'bar']
     processes = (flexmock(),)
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     process = flexmock(stdout=None)
     flexmock(module.subprocess).should_receive('Popen').with_args(
@@ -394,6 +462,7 @@ def test_execute_command_with_processes_calls_full_command_with_output_file():
     full_command = ['foo', 'bar']
     processes = (flexmock(),)
     output_file = flexmock(name='test')
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('Popen').with_args(
         full_command,
@@ -414,11 +483,12 @@ def test_execute_command_with_processes_calls_full_command_with_output_file():
 def test_execute_command_with_processes_calls_full_command_without_capturing_output():
     full_command = ['foo', 'bar']
     processes = (flexmock(),)
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('Popen').with_args(
         full_command, stdin=None, stdout=None, stderr=None, shell=False, env=None, cwd=None
     ).and_return(flexmock(wait=lambda: 0)).once()
-    flexmock(module).should_receive('exit_code_indicates_error').and_return(False)
+    flexmock(module).should_receive('interpret_exit_code').and_return(module.Exit_status.SUCCESS)
     flexmock(module).should_receive('log_outputs')
 
     output = module.execute_command_with_processes(
@@ -432,6 +502,7 @@ def test_execute_command_with_processes_calls_full_command_with_input_file():
     full_command = ['foo', 'bar']
     processes = (flexmock(),)
     input_file = flexmock(name='test')
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('Popen').with_args(
         full_command,
@@ -452,6 +523,7 @@ def test_execute_command_with_processes_calls_full_command_with_input_file():
 def test_execute_command_with_processes_calls_full_command_with_shell():
     full_command = ['foo', 'bar']
     processes = (flexmock(),)
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('Popen').with_args(
         ' '.join(full_command),
@@ -472,6 +544,7 @@ def test_execute_command_with_processes_calls_full_command_with_shell():
 def test_execute_command_with_processes_calls_full_command_with_extra_environment():
     full_command = ['foo', 'bar']
     processes = (flexmock(),)
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('Popen').with_args(
         full_command,
@@ -494,6 +567,7 @@ def test_execute_command_with_processes_calls_full_command_with_extra_environmen
 def test_execute_command_with_processes_calls_full_command_with_working_directory():
     full_command = ['foo', 'bar']
     processes = (flexmock(),)
+    flexmock(module).should_receive('log_command')
     flexmock(module.os, environ={'a': 'b'})
     flexmock(module.subprocess).should_receive('Popen').with_args(
         full_command,
@@ -515,6 +589,7 @@ def test_execute_command_with_processes_calls_full_command_with_working_director
 
 def test_execute_command_with_processes_kills_processes_on_error():
     full_command = ['foo', 'bar']
+    flexmock(module).should_receive('log_command')
     process = flexmock(stdout=flexmock(read=lambda count: None))
     process.should_receive('poll')
     process.should_receive('kill').once()
