@@ -69,7 +69,11 @@ def test_should_do_markup_prefers_any_false_config_value():
 
 
 def test_should_do_markup_respects_PY_COLORS_environment_variable():
-    flexmock(module.os.environ).should_receive('get').and_return('True')
+    flexmock(module.os.environ).should_receive('get').with_args('PY_COLORS', None).and_return(
+        'True'
+    )
+    flexmock(module.os.environ).should_receive('get').with_args('NO_COLOR', None).and_return(None)
+
     flexmock(module).should_receive('to_bool').and_return(True)
 
     assert module.should_do_markup(no_color=False, configs={}) is True
@@ -82,7 +86,7 @@ def test_should_do_markup_prefers_no_color_value_to_config_value():
     )
 
 
-def test_should_do_markup_prefers_config_value_to_PY_COLORS():
+def test_should_do_markup_prefers_config_value_to_environment_variables():
     flexmock(module.os.environ).should_receive('get').and_return('True')
     flexmock(module).should_receive('to_bool').and_return(True)
 
@@ -92,7 +96,7 @@ def test_should_do_markup_prefers_config_value_to_PY_COLORS():
     )
 
 
-def test_should_do_markup_prefers_no_color_value_to_PY_COLORS():
+def test_should_do_markup_prefers_no_color_value_to_environment_variables():
     flexmock(module.os.environ).should_receive('get').and_return('True')
     flexmock(module).should_receive('to_bool').and_return(True)
 
@@ -107,13 +111,42 @@ def test_should_do_markup_respects_interactive_console_value():
 
 
 def test_should_do_markup_prefers_PY_COLORS_to_interactive_console_value():
-    flexmock(module.os.environ).should_receive('get').and_return('True')
+    flexmock(module.os.environ).should_receive('get').with_args('PY_COLORS', None).and_return(
+        'True'
+    )
+    flexmock(module.os.environ).should_receive('get').with_args('NO_COLOR', None).and_return(None)
     flexmock(module).should_receive('to_bool').and_return(True)
     flexmock(module).should_receive('interactive_console').and_return(False)
 
     assert module.should_do_markup(no_color=False, configs={}) is True
 
 
+def test_should_do_markup_prefers_NO_COLOR_to_interactive_console_value():
+    flexmock(module.os.environ).should_receive('get').with_args('PY_COLORS', None).and_return(None)
+    flexmock(module.os.environ).should_receive('get').with_args('NO_COLOR', None).and_return('True')
+    flexmock(module).should_receive('interactive_console').and_return(False)
+
+    assert module.should_do_markup(no_color=False, configs={}) is False
+
+
+def test_should_do_markup_respects_NO_COLOR_environment_variable():
+    flexmock(module.os.environ).should_receive('get').with_args('NO_COLOR', None).and_return('True')
+    flexmock(module.os.environ).should_receive('get').with_args('PY_COLORS', None).and_return(None)
+
+    assert module.should_do_markup(no_color=False, configs={}) is False
+
+
+def test_should_do_markup_prefers_NO_COLOR_to_PY_COLORS():
+    flexmock(module.os.environ).should_receive('get').with_args('PY_COLORS', None).and_return(
+        'True'
+    )
+    flexmock(module.os.environ).should_receive('get').with_args('NO_COLOR', None).and_return(
+        'SomeValue'
+    )
+
+    assert module.should_do_markup(no_color=False, configs={}) is False
+
+
 def test_multi_stream_handler_logs_to_handler_for_log_level():
     error_handler = flexmock()
     error_handler.should_receive('emit').once()
@@ -177,11 +210,9 @@ def test_add_logging_level_skips_global_setting_if_already_set():
 def test_configure_logging_with_syslog_log_level_probes_for_log_socket_on_linux():
     flexmock(module).should_receive('add_custom_log_levels')
     flexmock(module.logging).ANSWER = module.ANSWER
-    flexmock(module).should_receive('Multi_stream_handler').and_return(
-        flexmock(
-            setFormatter=lambda formatter: None, setLevel=lambda level: None, level=logging.INFO
-        )
-    )
+    multi_stream_handler = flexmock(setLevel=lambda level: None, level=logging.INFO)
+    multi_stream_handler.should_receive('setFormatter').once()
+    flexmock(module).should_receive('Multi_stream_handler').and_return(multi_stream_handler)
     flexmock(module).should_receive('Console_color_formatter')
     flexmock(module).should_receive('interactive_console').and_return(False)
     flexmock(module.logging).should_receive('basicConfig').with_args(
@@ -199,11 +230,9 @@ def test_configure_logging_with_syslog_log_level_probes_for_log_socket_on_linux(
 def test_configure_logging_with_syslog_log_level_probes_for_log_socket_on_macos():
     flexmock(module).should_receive('add_custom_log_levels')
     flexmock(module.logging).ANSWER = module.ANSWER
-    flexmock(module).should_receive('Multi_stream_handler').and_return(
-        flexmock(
-            setFormatter=lambda formatter: None, setLevel=lambda level: None, level=logging.INFO
-        )
-    )
+    multi_stream_handler = flexmock(setLevel=lambda level: None, level=logging.INFO)
+    multi_stream_handler.should_receive('setFormatter').once()
+    flexmock(module).should_receive('Multi_stream_handler').and_return(multi_stream_handler)
     flexmock(module).should_receive('Console_color_formatter')
     flexmock(module).should_receive('interactive_console').and_return(False)
     flexmock(module.logging).should_receive('basicConfig').with_args(
@@ -222,11 +251,9 @@ def test_configure_logging_with_syslog_log_level_probes_for_log_socket_on_macos(
 def test_configure_logging_with_syslog_log_level_probes_for_log_socket_on_freebsd():
     flexmock(module).should_receive('add_custom_log_levels')
     flexmock(module.logging).ANSWER = module.ANSWER
-    flexmock(module).should_receive('Multi_stream_handler').and_return(
-        flexmock(
-            setFormatter=lambda formatter: None, setLevel=lambda level: None, level=logging.INFO
-        )
-    )
+    multi_stream_handler = flexmock(setLevel=lambda level: None, level=logging.INFO)
+    multi_stream_handler.should_receive('setFormatter').once()
+    flexmock(module).should_receive('Multi_stream_handler').and_return(multi_stream_handler)
     flexmock(module).should_receive('Console_color_formatter')
     flexmock(module).should_receive('interactive_console').and_return(False)
     flexmock(module.logging).should_receive('basicConfig').with_args(
@@ -246,11 +273,9 @@ def test_configure_logging_with_syslog_log_level_probes_for_log_socket_on_freebs
 def test_configure_logging_without_syslog_log_level_skips_syslog():
     flexmock(module).should_receive('add_custom_log_levels')
     flexmock(module.logging).ANSWER = module.ANSWER
-    flexmock(module).should_receive('Multi_stream_handler').and_return(
-        flexmock(
-            setFormatter=lambda formatter: None, setLevel=lambda level: None, level=logging.INFO
-        )
-    )
+    multi_stream_handler = flexmock(setLevel=lambda level: None, level=logging.INFO)
+    multi_stream_handler.should_receive('setFormatter').once()
+    flexmock(module).should_receive('Multi_stream_handler').and_return(multi_stream_handler)
     flexmock(module).should_receive('Console_color_formatter')
     flexmock(module.logging).should_receive('basicConfig').with_args(
         level=logging.INFO, handlers=list
@@ -264,11 +289,9 @@ def test_configure_logging_without_syslog_log_level_skips_syslog():
 def test_configure_logging_skips_syslog_if_not_found():
     flexmock(module).should_receive('add_custom_log_levels')
     flexmock(module.logging).ANSWER = module.ANSWER
-    flexmock(module).should_receive('Multi_stream_handler').and_return(
-        flexmock(
-            setFormatter=lambda formatter: None, setLevel=lambda level: None, level=logging.INFO
-        )
-    )
+    multi_stream_handler = flexmock(setLevel=lambda level: None, level=logging.INFO)
+    multi_stream_handler.should_receive('setFormatter').once()
+    flexmock(module).should_receive('Multi_stream_handler').and_return(multi_stream_handler)
     flexmock(module).should_receive('Console_color_formatter')
     flexmock(module.logging).should_receive('basicConfig').with_args(
         level=logging.INFO, handlers=list
@@ -282,11 +305,9 @@ def test_configure_logging_skips_syslog_if_not_found():
 def test_configure_logging_skips_log_file_if_log_file_logging_is_disabled():
     flexmock(module).should_receive('add_custom_log_levels')
     flexmock(module.logging).DISABLED = module.DISABLED
-    flexmock(module).should_receive('Multi_stream_handler').and_return(
-        flexmock(
-            setFormatter=lambda formatter: None, setLevel=lambda level: None, level=logging.INFO
-        )
-    )
+    multi_stream_handler = flexmock(setLevel=lambda level: None, level=logging.INFO)
+    multi_stream_handler.should_receive('setFormatter').once()
+    flexmock(module).should_receive('Multi_stream_handler').and_return(multi_stream_handler)
 
     flexmock(module.logging).should_receive('basicConfig').with_args(
         level=logging.INFO, handlers=list
@@ -303,11 +324,9 @@ def test_configure_logging_skips_log_file_if_log_file_logging_is_disabled():
 def test_configure_logging_to_log_file_instead_of_syslog():
     flexmock(module).should_receive('add_custom_log_levels')
     flexmock(module.logging).ANSWER = module.ANSWER
-    flexmock(module).should_receive('Multi_stream_handler').and_return(
-        flexmock(
-            setFormatter=lambda formatter: None, setLevel=lambda level: None, level=logging.INFO
-        )
-    )
+    multi_stream_handler = flexmock(setLevel=lambda level: None, level=logging.INFO)
+    multi_stream_handler.should_receive('setFormatter').once()
+    flexmock(module).should_receive('Multi_stream_handler').and_return(multi_stream_handler)
 
     flexmock(module.logging).should_receive('basicConfig').with_args(
         level=logging.DEBUG, handlers=list
@@ -330,11 +349,9 @@ def test_configure_logging_to_log_file_instead_of_syslog():
 def test_configure_logging_to_both_log_file_and_syslog():
     flexmock(module).should_receive('add_custom_log_levels')
     flexmock(module.logging).ANSWER = module.ANSWER
-    flexmock(module).should_receive('Multi_stream_handler').and_return(
-        flexmock(
-            setFormatter=lambda formatter: None, setLevel=lambda level: None, level=logging.INFO
-        )
-    )
+    multi_stream_handler = flexmock(setLevel=lambda level: None, level=logging.INFO)
+    multi_stream_handler.should_receive('setFormatter').once()
+    flexmock(module).should_receive('Multi_stream_handler').and_return(multi_stream_handler)
 
     flexmock(module.logging).should_receive('basicConfig').with_args(
         level=logging.DEBUG, handlers=list
@@ -363,11 +380,9 @@ def test_configure_logging_to_log_file_formats_with_custom_log_format():
     flexmock(module.logging).should_receive('Formatter').with_args(
         '{message}', style='{'  # noqa: FS003
     ).once()
-    flexmock(module).should_receive('Multi_stream_handler').and_return(
-        flexmock(
-            setFormatter=lambda formatter: None, setLevel=lambda level: None, level=logging.INFO
-        )
-    )
+    multi_stream_handler = flexmock(setLevel=lambda level: None, level=logging.INFO)
+    multi_stream_handler.should_receive('setFormatter').once()
+    flexmock(module).should_receive('Multi_stream_handler').and_return(multi_stream_handler)
 
     flexmock(module).should_receive('interactive_console').and_return(False)
     flexmock(module.logging).should_receive('basicConfig').with_args(
@@ -391,11 +406,9 @@ def test_configure_logging_to_log_file_formats_with_custom_log_format():
 def test_configure_logging_skips_log_file_if_argument_is_none():
     flexmock(module).should_receive('add_custom_log_levels')
     flexmock(module.logging).ANSWER = module.ANSWER
-    flexmock(module).should_receive('Multi_stream_handler').and_return(
-        flexmock(
-            setFormatter=lambda formatter: None, setLevel=lambda level: None, level=logging.INFO
-        )
-    )
+    multi_stream_handler = flexmock(setLevel=lambda level: None, level=logging.INFO)
+    multi_stream_handler.should_receive('setFormatter').once()
+    flexmock(module).should_receive('Multi_stream_handler').and_return(multi_stream_handler)
 
     flexmock(module.logging).should_receive('basicConfig').with_args(
         level=logging.INFO, handlers=list
@@ -404,3 +417,19 @@ def test_configure_logging_skips_log_file_if_argument_is_none():
     flexmock(module.logging.handlers).should_receive('WatchedFileHandler').never()
 
     module.configure_logging(console_log_level=logging.INFO, log_file=None)
+
+
+def test_configure_logging_skips_console_color_formatter_if_color_disabled():
+    flexmock(module).should_receive('add_custom_log_levels')
+    flexmock(module.logging).ANSWER = module.ANSWER
+    multi_stream_handler = flexmock(setLevel=lambda level: None, level=logging.INFO)
+    multi_stream_handler.should_receive('setFormatter').never()
+    flexmock(module).should_receive('Multi_stream_handler').and_return(multi_stream_handler)
+
+    flexmock(module.logging).should_receive('basicConfig').with_args(
+        level=logging.INFO, handlers=list
+    )
+    flexmock(module.os.path).should_receive('exists').and_return(False)
+    flexmock(module.logging.handlers).should_receive('WatchedFileHandler').never()
+
+    module.configure_logging(console_log_level=logging.INFO, log_file=None, color_enabled=False)
